@@ -9,7 +9,7 @@ This file is part of nutra, a nutrient analysis program.
     https://pypi.org/project/nutra/
 
 nutra is an extensible nutrient analysis and composition application.
-Copyright (C) 2018-2022  Shane Jaroch <nutratracker@gmail.com>
+Copyright (C) 2018-2022  Shane Jaroch <chown_tee@proton.me>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ from ntclient.utils.exceptions import SqlException
 colorama_init()
 
 
-def build_argparser():
+def build_argparser() -> argparse.ArgumentParser:
     """Adds all subparsers and parsing logic"""
 
     arg_parser = argparse.ArgumentParser(prog=__title__)
@@ -62,10 +62,7 @@ def build_argparser():
         "-d", "--debug", action="store_true", help="enable detailed error messages"
     )
     arg_parser.add_argument(
-        "--no-pager",
-        dest="no_paging",
-        action="store_true",
-        help="disable paging (print full output)",
+        "--no-pager", action="store_true", help="disable paging (print full output)"
     )
 
     # Subparsers
@@ -75,37 +72,52 @@ def build_argparser():
     return arg_parser
 
 
-def main(args=None):
-    """Main method for CLI"""
+def main(args: list = None) -> int:
+    """
+    Main method for CLI
+
+    @param args: List[str]
+    """
 
     start_time = time.time()
     arg_parser = build_argparser()
     argcomplete.autocomplete(arg_parser)
 
-    def parse_args():
+    def parse_args() -> argparse.Namespace:
+        """Returns parsed args"""
         if args is None:
             return arg_parser.parse_args()
         return arg_parser.parse_args(args=args)
 
-    def func():
-        if hasattr(args, "func"):
+    def func(parser: argparse.Namespace) -> tuple:
+        """Executes a function for a given argument call to the parser"""
+        if hasattr(parser, "func"):
+            # More than an empty command, so initialize the storage folder
             persistence_init()
-            args_dict = dict(vars(args))
-            for expected_arg in ["func", "debug", "no_paging"]:
+
+            args_dict = dict(vars(parser))
+            for expected_arg in ["func", "debug", "no_pager"]:
                 args_dict.pop(expected_arg)
+
             # Run function
             if args_dict:
-                return args.func(args=args)
-            return args.func()
-        return 1, arg_parser.print_help()
+                return parser.func(args=parser)
+            return parser.func()
 
-    args = parse_args()
-    set_flags(args)
+        # Otherwise print help
+        arg_parser.print_help()
+        return 0, None
+
+    # Build the parser, set flags
+    _parser = parse_args()
+    set_flags(_parser)
     from ntclient import DEBUG  # pylint: disable=import-outside-toplevel
 
-    exit_code = None
+    # TODO: bug reporting?
+    # Try to run the function
+    exit_code = 1
     try:
-        exit_code, *_results = func()
+        exit_code, *_results = func(_parser)
         return exit_code
     except SqlException as sql_exception:
         print("Issue with an sqlite database: " + repr(sql_exception))
@@ -117,7 +129,7 @@ def main(args=None):
         if DEBUG:
             raise
     except URLError as url_error:
-        print("Connection error, check your internet: " + url_error.reason)
+        print("Connection error, check your internet: " + repr(url_error.reason))
         if DEBUG:
             raise
     except Exception as exception:  # pylint: disable=broad-except
@@ -130,6 +142,8 @@ def main(args=None):
             print("\nExecuted in: %s ms" % round(exc_time * 1000, 1))
             print("Exit code: %s" % exit_code)
 
+    return exit_code
+
 
 if __name__ == "__main__":
     sys.exit(main())
