@@ -1,9 +1,10 @@
 """Main module for things related to argparse"""
 
-from ntclient.argparser import funcs as parser_funcs, types
+from ntclient.argparser import funcs as parser_funcs
+from ntclient.argparser import types
 
 
-def build_subcommands(subparsers):
+def build_subcommands(subparsers) -> None:
     """Attaches subcommands to main parser"""
     build_init_subcommand(subparsers)
     build_nt_subcommand(subparsers)
@@ -12,13 +13,12 @@ def build_subcommands(subparsers):
     build_analyze_subcommand(subparsers)
     build_day_subcommand(subparsers)
     build_recipe_subcommand(subparsers)
-    build_biometric_subcommand(subparsers)
 
 
 ################################################################################
 # Methods to build subparsers, and attach back to main arg_parser
 ################################################################################
-def build_init_subcommand(subparsers):
+def build_init_subcommand(subparsers) -> None:
     """Self running init command"""
     init_parser = subparsers.add_parser(
         "init", help="setup profiles, USDA and NT database"
@@ -32,7 +32,7 @@ def build_init_subcommand(subparsers):
     init_parser.set_defaults(func=parser_funcs.init)
 
 
-def build_nt_subcommand(subparsers):
+def build_nt_subcommand(subparsers) -> None:
     """Lists out nutrients details with computed totals and averages"""
     nutrient_parser = subparsers.add_parser(
         "nt", help="list out nutrients and their info"
@@ -40,7 +40,7 @@ def build_nt_subcommand(subparsers):
     nutrient_parser.set_defaults(func=parser_funcs.nutrients)
 
 
-def build_search_subcommand(subparsers):
+def build_search_subcommand(subparsers) -> None:
     """Search: terms [terms ... ]"""
     search_parser = subparsers.add_parser(
         "search", help="search foods by name, list overview info"
@@ -66,7 +66,7 @@ def build_search_subcommand(subparsers):
     search_parser.set_defaults(func=parser_funcs.search)
 
 
-def build_sort_subcommand(subparsers):
+def build_sort_subcommand(subparsers) -> None:
     """Sort foods ranked by nutr_id, per 100g or 200kcal"""
     sort_parser = subparsers.add_parser("sort", help="sort foods by nutrient ID")
     sort_parser.add_argument(
@@ -86,7 +86,7 @@ def build_sort_subcommand(subparsers):
     sort_parser.set_defaults(func=parser_funcs.sort)
 
 
-def build_analyze_subcommand(subparsers):
+def build_analyze_subcommand(subparsers) -> None:
     """Analyzes (foods only for now)"""
     analyze_parser = subparsers.add_parser("anl", help="analyze food(s)")
     analyze_parser.add_argument(
@@ -99,7 +99,7 @@ def build_analyze_subcommand(subparsers):
     analyze_parser.set_defaults(func=parser_funcs.analyze)
 
 
-def build_day_subcommand(subparsers):
+def build_day_subcommand(subparsers) -> None:
     """Analyzes a DAY.csv, uses new colored progress bar spec"""
     day_parser = subparsers.add_parser(
         "day", help="analyze a DAY.csv file, RDAs optional"
@@ -121,7 +121,7 @@ def build_day_subcommand(subparsers):
     day_parser.set_defaults(func=parser_funcs.day)
 
 
-def build_recipe_subcommand(subparsers):
+def build_recipe_subcommand(subparsers) -> None:
     """View, add, edit, delete recipes"""
     recipe_parser = subparsers.add_parser("recipe", help="list and analyze recipes")
     recipe_subparsers = recipe_parser.add_subparsers(title="recipe subcommands")
@@ -151,25 +151,3 @@ def build_recipe_subcommand(subparsers):
     recipe_delete_parser.set_defaults(func=parser_funcs.recipe_delete)
 
     recipe_parser.set_defaults(func=parser_funcs.recipes)
-
-
-def build_biometric_subcommand(subparsers):
-    """View biometrics, and view, add, edit, delete log entries"""
-    bio_parser = subparsers.add_parser("bio", help="view, add, remove biometric logs")
-    bio_subparsers = bio_parser.add_subparsers(title="biometric subcommands")
-
-    bio_log_parser = bio_subparsers.add_parser("log", help="manage biometric logs")
-    bio_log_subparsers = bio_log_parser.add_subparsers(
-        title="biometric log subcommands"
-    )
-    bio_log_parser.set_defaults(func=parser_funcs.bio_log)
-
-    bio_log_add_parser = bio_log_subparsers.add_parser(
-        "add", help="add a biometric log"
-    )
-    bio_log_add_parser.add_argument(
-        "biometric_val", help="id,value pairs, e.g. 22,59 23,110 24,65 ", nargs="+"
-    )
-    bio_log_add_parser.set_defaults(func=parser_funcs.bio_log_add)
-
-    bio_parser.set_defaults(func=parser_funcs.bio)
