@@ -3,12 +3,12 @@ import os
 import sqlite3
 
 from ntclient import NT_DB_NAME, NUTRA_DIR, __db_target_nt__
-from ntclient.persistence.sql import _sql, version
+from ntclient.persistence.sql import _sql, _sql_headers, version
 from ntclient.utils.exceptions import SqlConnectError, SqlInvalidVersionError
 
 
-def nt_sqlite_connect(version_check=True):
-    """Connects to the nt.sqlite file, or throws an exception"""
+def nt_sqlite_connect(version_check=True) -> sqlite3.Connection:
+    """Connects to the nt.sqlite3 file, or throws an exception"""
     db_path = os.path.join(NUTRA_DIR, NT_DB_NAME)
     if os.path.isfile(db_path):
         con = sqlite3.connect(db_path)
@@ -20,7 +20,8 @@ def nt_sqlite_connect(version_check=True):
                 "ERROR: nt target [{0}] mismatch actual [{1}] ".format(
                     __db_target_nt__, nt_ver()
                 )
-                + "upgrades not supported, please remove '~/.nutra/nt.sqlite' and run 'nutra init'"
+                + "upgrades not supported, please remove '~/.nutra/nt.sqlite3'"
+                "and re-run 'nutra init'"
             )
         return con
 
@@ -28,13 +29,19 @@ def nt_sqlite_connect(version_check=True):
     raise SqlConnectError("ERROR: nt database doesn't exist, please run `nutra init`")
 
 
-def nt_ver():
-    """Gets version string for nt.sqlite database"""
+def nt_ver() -> str:
+    """Gets version string for nt.sqlite3 database"""
     con = nt_sqlite_connect(version_check=False)
     return version(con)
 
 
-def sql(query, values=None, headers=False):
-    """Executes a SQL command to nt.sqlite"""
+def sql(query, values=None) -> list:
+    """Executes a SQL command to nt.sqlite3"""
     con = nt_sqlite_connect()
-    return _sql(con, query, db_name="nt", values=values, headers=headers)
+    return _sql(con, query, db_name="nt", values=values)
+
+
+def sql_headers(query, values=None) -> tuple:
+    """Executes a SQL command to nt.sqlite3"""
+    con = nt_sqlite_connect()
+    return _sql_headers(con, query, db_name="nt", values=values)
